dengueRio: Dengue in Rio de Janeiro state

dengueRioR Documentation

Dengue in Rio de Janeiro state

Description

A data.frame containing weekly dengue cases for the different municipalities in the state of Rio de Janeiro for the period 2017-2022.

Usage

data(dengueRio)

Format

dengueRio

A data frame with 28,796 rows and 4 columns:

muni_code

Municipality code

date

Starting date of the week (Sunday)

cases

Number of dengue cases

pop

Population

\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1371/journal.pntd.0010746")}

epidesc documentation built on Aug. 8, 2026, 1:06 a.m.