desc_Cnf: Cnf

View source: R/desc-cases.R

desc_CnfR Documentation

Cnf

Description

Frequency of periods of consecutive 'n' weeks or longer with at least 'x' cases.

Usage

desc_Cnf(df, n, x)

Arguments

df

A data.frame with a numeric 'cases' column.

n

Number of consecutive weeks.

x

Number of cases.

Details

This function is designed to be called by desc_year on data that has already been split into a single epidemiological year for a single spatial unit. Using it directly outside of that context is not recommended, as no input validation is performed.

Value

The computed Cnf epidescriptor.

Examples

# Single spatial unit and epidemiological year
oneyear <- dengueRio[dengueRio$muni_code == 330455, ]
oneyear$time <- epiyearweek(oneyear$date)
oneyear <- oneyear[substr(oneyear$time, 1, 4) == "2019", ]
desc_Cnf(oneyear, 3, 50)

epidesc documentation built on Aug. 8, 2026, 1:06 a.m.