desc_Inc: Inc

View source: R/desc-inc.R

desc_IncR Documentation

Inc

Description

Disease incidence per 'p' persons.

Usage

desc_Inc(df, p)

Arguments

df

A data.frame with numeric 'cases' and 'pop' columns.

p

Number of persons representing the scale of the incidence.

Details

This function is designed to be called by desc_year on data that has already been split into a single epidemiological year for a single spatial unit. Using it directly outside of that context is not recommended, as no input validation is performed.

Value

The computed Inc epidescriptor.

Examples

# Single spatial unit and epidemiological year
oneyear <- dengueRio[dengueRio$muni_code == 330455, ]
oneyear$time <- epiyearweek(oneyear$date)
oneyear <- oneyear[substr(oneyear$time, 1, 4) == "2019", ]
desc_Inc(oneyear, 100000)

epidesc documentation built on Aug. 8, 2026, 1:06 a.m.