| desc_Isof | R Documentation |
Number of weeks with isolated cases, i.e. weeks with 0 cases both in the previous and following week.
desc_Isof(df)
df |
A data.frame with a numeric 'cases' column. |
This function is designed to be called by desc_year on data that has already been split into a single epidemiological year for a single spatial unit. Using it directly outside of that context is not recommended, as no input validation is performed.
The computed Isof epidescriptor.
# Single spatial unit and epidemiological year
oneyear <- dengueRio[dengueRio$muni_code == 330455, ]
oneyear$time <- epiyearweek(oneyear$date)
oneyear <- oneyear[substr(oneyear$time, 1, 4) == "2019", ]
desc_Isof(oneyear)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.