epidesc-package: epidesc: Calculation of Epidemiological Descriptors

epidesc-packageR Documentation

epidesc: Calculation of Epidemiological Descriptors

Description

Provides tools to easily compute a series of epidemiological indicators to characterise different transmission profiles of infectious diseases with a simple pipeline: format the dates in epiyearweek format, choose the descriptors and their parameters, and compute them. The package is based on the publication 'How heterogeneous is the dengue transmission profile in Brazil? A study in six Brazilian states' \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1371/journal.pntd.0010746")}.

Author(s)

Maintainer: Carles Milà carles.milagarcia@bsc.es (ORCID)

Authors:

See Also

Useful links:


epidesc documentation built on Aug. 8, 2026, 1:06 a.m.