| dengueRio | R Documentation |
A data.frame containing weekly dengue cases for the different municipalities in the state of Rio de Janeiro for the period 2017-2022.
data(dengueRio)
dengueRioA data frame with 28,796 rows and 4 columns:
Municipality code
Starting date of the week (Sunday)
Number of dengue cases
Population
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.