| desc_Inc | R Documentation |
Disease incidence per 'p' persons.
desc_Inc(df, p)
df |
A data.frame with numeric 'cases' and 'pop' columns. |
p |
Number of persons representing the scale of the incidence. |
This function is designed to be called by desc_year on data that has already been split into a single epidemiological year for a single spatial unit. Using it directly outside of that context is not recommended, as no input validation is performed.
The computed Inc epidescriptor.
# Single spatial unit and epidemiological year
oneyear <- dengueRio[dengueRio$muni_code == 330455, ]
oneyear$time <- epiyearweek(oneyear$date)
oneyear <- oneyear[substr(oneyear$time, 1, 4) == "2019", ]
desc_Inc(oneyear, 100000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.