| desc_p | R Documentation |
Proportion of weeks with at least 'x' cases.
desc_p(df, x)
df |
A data.frame with a numeric 'cases' column. |
x |
Number of cases. |
This function is designed to be called by desc_year on data that has already been split into a single epidemiological year for a single spatial unit. Using it directly outside of that context is not recommended, as no input validation is performed.
The computed p epidescriptor.
# Single spatial unit and epidemiological year
oneyear <- dengueRio[dengueRio$muni_code == 330455, ]
oneyear$time <- epiyearweek(oneyear$date)
oneyear <- oneyear[substr(oneyear$time, 1, 4) == "2019", ]
desc_p(oneyear, 50)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.